(* 
 * Copyright (c) 2001, 2002 The University of Wroclaw.
 * All rights reserved. See file COPYRIGHT for details about licensing.
 *
 * $Id: gontbind.mli,v 1.6 2002/02/25 11:09:13 malekith Exp $
 *
 * Module interface: Gontbind
 * Description: Interface to symbol binder. (see .ml file for more info)
 *)

open Gonttree

type ctx

(* Return initial binding context for named module. *)
val init_bind : (* module name *) string -> (* iface *) bool -> ctx

(* Modify decl in place, adding symbol entries to Ref terms. This mustn't be
 * called more then once in a top level declaration (i.e. don't call it for 
 * nested functions). *)
val bind : ctx -> decl -> ctx

(* Return list of stmts given in `section init/fini'. *)
val init_stmts : ctx -> stmt list
val fini_stmts : ctx -> stmt list

(* Return list of symbols, at given scoping (function) level, that needs 
 * to put into the closure because they are referenced in stmts. *)
val closure : int -> stmt -> (bool * symbol list)

(* Save module interface. *)
val finalize_module : out_channel -> ctx -> unit

(* Return list of modules used by current translation unit. *)
val used_modules_list : unit -> string list
;;
